@@ -282,6 +282,9 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
                 NotificationCenter.default.addObserver(forName: NSNotification.Name(rawValue: VLCPlaybackServicePlaybackDidResume),
                                                        object: nil, queue: OperationQueue.main, using: {_ in
                     self.animateCurrentlyPlayingState()
+                    if let parentCollectionView = self.superview as? UICollectionView {
+                        parentCollectionView.reloadData()
+                    }
                 })
                 animateCurrentlyPlayingState()
                 backupThumbnail = audiotrack.thumbnailImage()
@@ -363,7 +366,9 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
         thumbnailView.layer.cornerRadius = thumbnailView.frame.size.width / 2.0
         titleLabel.text = artist.artistName()
         accessibilityLabel = artist.accessibilityText()
-        sizeDescriptionLabel.text = artist.numberOfTracksString()
+        let numberOfAlbums = artist.albumsCount()
+        sizeDescriptionLabel.text = numberOfAlbums == 0 ? artist.numberOfTracksString() :
+                                    String(format: "%@ · %@", artist.numberOfAlbumsString(), artist.numberOfTracksString())
         thumbnailView.image = artist.thumbnail()
         scrollView.isScrollEnabled = false
         updateSizeDescriptionLabelConstraint()
@@ -390,7 +395,7 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
         newLabel.isHidden = true
         titleLabel.text = playlist.name
         accessibilityLabel = playlist.accessibilityText()
-        sizeDescriptionLabel.text = playlist.numberOfTracksString()
+        sizeDescriptionLabel.text = playlist.numberOfTracksString() + " · " + playlist.durationString()
         thumbnailView.layer.cornerRadius = 3
         thumbnailView.image = playlist.thumbnail()
         dragIndicatorImageView.image = UIImage(named: "disclosureChevron")
@@ -411,7 +416,7 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
             return
         }
 
-        sizeDescriptionLabel.text = String(format: "%@ — %@", mediaGroup.numberOfTracksString(), mediaGroup.mediaDuration())
+        sizeDescriptionLabel.text = String(format: "%@ · %@", mediaGroup.numberOfTracksString(), mediaGroup.mediaDuration())
         titleLabel.text = mediaGroup.title()
         accessibilityLabel = mediaGroup.accessibilityText()
 
@@ -480,8 +485,12 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
 
     private func setupGestureRecognizer() {
         let mediaTapGesture = UITapGestureRecognizer(target: self, action: #selector(mediaTapped(_:)))
-
         scrollContentView.addGestureRecognizer(mediaTapGesture)
+
+        // Add tap gesture recognizer to disable the item selection when tapping on the drag image view
+        let tapGestureRecognizer = UITapGestureRecognizer(target: self, action: nil)
+        dragIndicatorImageView.addGestureRecognizer(tapGestureRecognizer)
+        dragIndicatorImageView.isUserInteractionEnabled = true
     }
 
     @objc private func mediaTapped(_ sender: UITapGestureRecognizer) {
@@ -557,7 +566,7 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
     // MARK: - Class methods
 
     override class func numberOfColumns(for width: CGFloat) -> CGFloat {
-        if width <= DeviceDimensions.iPhone12ProMaxPortrait.rawValue {
+        if width <= DeviceDimensions.iPhone14ProMaxPortrait.rawValue {
             return 1
         } else if width <= DeviceDimensions.iPadLandscape.rawValue {
             return 2
