@@ -2,9 +2,14 @@
 * SettingsSection.swift
 * VLC for iOS
 *****************************************************************************
-* Copyright (c) 2020 VideoLAN. All rights reserved.
+* Copyright (c) 2020-2023 VideoLAN. All rights reserved.
 *
 * Authors: Swapnanil Dhol <swapnanildhol # gmail.com>
+*          Soomin Lee < bubu@mikan.io >
+*          Edgar Fouillet <vlc # edgar.fouillet.eu>
+*          Diogo Simao Marques <dogo@videolabs.io>
+*          Felix Paul Kühne <fkuehne # videolan.org>
+*          Eshan Singh <eeeshan789@icloud.com>
 *
 * Refer to the COPYING file of the official project for license.
 *****************************************************************************/
@@ -14,6 +19,7 @@ import LocalAuthentication
 
 enum SettingsSection: Int, CaseIterable, CustomStringConvertible {
     case main
+    case donation
     case generic
     case privacy
     case gestureControl
@@ -24,11 +30,14 @@ enum SettingsSection: Int, CaseIterable, CustomStringConvertible {
     case mediaLibrary
     case network
     case lab
+    case reset
 
     var description: String {
         switch self {
         case .main:
             return ""
+        case .donation:
+            return ""
         case .generic:
             return "SETTINGS_GENERIC_TITLE"
         case .privacy:
@@ -49,6 +58,8 @@ enum SettingsSection: Int, CaseIterable, CustomStringConvertible {
             return "SETTINGS_NETWORK"
         case .lab:
             return "SETTINGS_LAB"
+        case .reset:
+            return "SETTINGS_RESET_TITLE"
         }
     }
 }
@@ -56,7 +67,6 @@ enum SettingsSection: Int, CaseIterable, CustomStringConvertible {
 enum MainOptions: Int, CaseIterable, SectionType {
     case privacy
     case appearance
-    case blackTheme
 
     var description: String {
         switch self {
@@ -64,8 +74,6 @@ enum MainOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_PRIVACY_TITLE"
         case .appearance:
             return "SETTINGS_DARKTHEME"
-        case .blackTheme:
-            return "SETTINGS_THEME_BLACK"
         }
     }
 
@@ -75,8 +83,6 @@ enum MainOptions: Int, CaseIterable, SectionType {
             return false
         case .appearance:
             return false
-        case .blackTheme:
-            return true
         }
     }
 
@@ -88,8 +94,6 @@ enum MainOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_PRIVACY_SUBTITLE"
         case .appearance:
             return "SETTINGS_THEME_SYSTEM"
-        case .blackTheme:
-            return "SETTINGS_THEME_BLACK_SUBTITLE"
         }
     }
 
@@ -99,12 +103,28 @@ enum MainOptions: Int, CaseIterable, SectionType {
             return kVLCSettingPasscodeOnKey
         case .appearance:
             return kVLCSettingAppTheme
-        case .blackTheme:
-            return kVLCSettingAppThemeBlack
         }
     }
 }
 
+enum DonationOptions: Int, CaseIterable, SectionType {
+    case donate
+
+    var description: String {
+        return "SETTINGS_DONATE"
+    }
+
+    var containsSwitch: Bool { return false }
+
+    var containsInfobutton: Bool { return false }
+
+    var subtitle: String? {
+        return "SETTINGS_DONATE_LONG"
+    }
+
+    var preferenceKey: String? { return nil }
+}
+
 enum GenericOptions: Int, CaseIterable, SectionType {
     case defaultPlaybackSpeed
     case continueAudioPlayback
@@ -144,7 +164,7 @@ enum GenericOptions: Int, CaseIterable, SectionType {
         case .continueVideoPlayback:
             return false
         case .automaticallyPlayNextItem:
-            return true
+            return false
         case .enableTextScrollingInMediaList:
             return true
         case .rememberPlayerState:
@@ -152,7 +172,16 @@ enum GenericOptions: Int, CaseIterable, SectionType {
         }
     }
 
-    var containsInfobutton: Bool { return false }
+    var containsInfobutton: Bool {
+        switch self {
+        case .continueAudioPlayback:
+            return true
+        case .continueVideoPlayback:
+            return true
+        default:
+            return false
+        }
+    }
 
     var subtitle: String? {
         switch self {
@@ -279,8 +308,12 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
     case swipeUpDownForBrightness
     case swipeRightLeftToSeek
     case pinchToClose
+    case forwardBackwardEqual
+    case tapSwipeEqual
     case forwardSkipLength
     case backwardSkipLength
+    case forwardSkipLengthSwipe
+    case backwardSkipLengthSwipe
 
     var containsInfobutton: Bool { return false }
 
@@ -296,14 +329,24 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return true
         case .pinchToClose:
             return true
+        case .forwardBackwardEqual:
+            return true
+        case .tapSwipeEqual:
+            return true
         case .forwardSkipLength:
             return false
         case .backwardSkipLength:
             return false
+        case .forwardSkipLengthSwipe:
+            return false
+        case .backwardSkipLengthSwipe:
+            return false
         }
     }
 
     var description: String {
+        let forwardBackwardEqual = UserDefaults.standard.bool(forKey: kVLCSettingPlaybackForwardBackwardEqual)
+        let tapSwipeEqual = UserDefaults.standard.bool(forKey: kVLCSettingPlaybackTapSwipeEqual)
         switch self {
         case .swipeUpDownForVolume:
             return "SETTINGS_GESTURES_VOLUME"
@@ -315,10 +358,31 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_GESTURES_SEEK"
         case .pinchToClose:
             return "SETTINGS_GESTURES_CLOSE"
+        case .forwardBackwardEqual:
+            return "SETTINGS_GESTURES_FORWARD_BACKWARD_EQUAL"
+        case .tapSwipeEqual:
+            return "SETTINGS_GESTURES_TAP_SWIPE_EQUAL"
         case .forwardSkipLength:
-            return "SETTINGS_PLAYBACK_SKIP_FORWARD"
+            if forwardBackwardEqual && tapSwipeEqual {
+                return "SETTINGS_PLAYBACK_SKIP_GENERIC"
+            } else if forwardBackwardEqual && !tapSwipeEqual {
+                return "SETTINGS_PLAYBACK_SKIP_TAP"
+            } else if !forwardBackwardEqual && !tapSwipeEqual {
+                return "SETTINGS_PLAYBACK_SKIP_FORWARD_TAP"
+            }
+            return  "SETTINGS_PLAYBACK_SKIP_FORWARD"
         case .backwardSkipLength:
-            return "SETTINGS_PLAYBACK_SKIP_BACKWARD"
+            if tapSwipeEqual {
+                return "SETTINGS_PLAYBACK_SKIP_BACKWARD"
+            }
+            return "SETTINGS_PLAYBACK_SKIP_BACKWARD_TAP"
+        case .forwardSkipLengthSwipe:
+            if forwardBackwardEqual {
+                return "SETTINGS_PLAYBACK_SKIP_SWIPE"
+            }
+            return "SETTINGS_PLAYBACK_SKIP_FORWARD_SWIPE"
+        case .backwardSkipLengthSwipe:
+            return "SETTINGS_PLAYBACK_SKIP_BACKWARD_SWIPE"
         }
     }
 
@@ -336,10 +400,18 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return kVLCSettingSeekGesture
         case .pinchToClose:
             return kVLCSettingCloseGesture
+        case .forwardBackwardEqual:
+            return kVLCSettingPlaybackForwardBackwardEqual
+        case .tapSwipeEqual:
+            return kVLCSettingPlaybackTapSwipeEqual
         case .forwardSkipLength:
             return kVLCSettingPlaybackForwardSkipLength
         case .backwardSkipLength:
             return kVLCSettingPlaybackBackwardSkipLength
+        case .forwardSkipLengthSwipe:
+            return kVLCSettingPlaybackForwardSkipLengthSwipe
+        case .backwardSkipLengthSwipe:
+            return kVLCSettingPlaybackBackwardSkipLengthSwipe
         }
     }
 }
@@ -376,7 +448,18 @@ enum VideoOptions: Int, CaseIterable, SectionType {
         }
     }
 
-    var containsInfobutton: Bool { return true }
+    var containsInfobutton: Bool {
+        switch self {
+        case .deBlockingFilter:
+            return true
+        case .deInterlace:
+            return true
+        case .hardwareDecoding:
+            return true
+        case .rememberPlayerBrightness:
+            return false
+        }
+    }
 
     var subtitle: String? {
         switch self {
@@ -406,6 +489,7 @@ enum VideoOptions: Int, CaseIterable, SectionType {
 }
 
 enum SubtitlesOptions: Int, CaseIterable, SectionType {
+    case disableSubtitles
     case font
     case relativeFontSize
     case useBoldFont
@@ -414,6 +498,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var description: String {
         switch self {
+        case .disableSubtitles:
+            return "SETTINGS_SUBTITLES_DISABLE"
         case .font:
             return "SETTINGS_SUBTITLES_FONT"
         case .relativeFontSize:
@@ -429,6 +515,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var containsSwitch: Bool {
         switch self {
+        case .disableSubtitles:
+            return true
         case .font:
             return false
         case .relativeFontSize:
@@ -444,6 +532,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var subtitle: String? {
         switch self {
+        case .disableSubtitles:
+            return "SETTINGS_SUBTITLES_DISABLE_LONG"
         case .font:
             return "Arial"
         case .relativeFontSize:
@@ -459,6 +549,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var preferenceKey: String? {
         switch self {
+        case .disableSubtitles:
+            return kVLCSettingDisableSubtitles
         case .font:
             return kVLCSettingSubtitlesFont
         case .relativeFontSize:
@@ -472,7 +564,7 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
         }
     }
 
-    var containsInfobutton: Bool { return false }
+    var containsInfobutton: Bool { return true }
 }
 
 enum CastingOptions: Int, CaseIterable, SectionType {
@@ -730,3 +822,17 @@ enum Lab: Int, CaseIterable, SectionType {
 
     var containsInfobutton: Bool { return false }
 }
+
+enum Reset: Int, CaseIterable, SectionType {
+    case resetOptions
+
+    var containsSwitch: Bool { return false }
+
+    var subtitle: String? { return nil }
+
+    var preferenceKey: String? { return kVLCResetSettings }
+
+    var containsInfobutton: Bool { return false }
+
+    var description: String { return "SETTINGS_RESET" }
+}
